常用按钮

常用按钮 | 内容提要

以下是每个按钮的简短说明

| 粗体文字样式
| 斜体文字样式
| 下划线文字样式
| 删除线文字样式
| 左对齐
| 居中对齐
| 右对齐
| 两端对齐
| 无序列表
| 有序列表
| 减少缩进量
| 增加缩进量
| 撤消上一操作
| 重做上一操作
| 插入新链接，点击 插入链接按钮 章节以查看更多内容。
| 删除当前选定的链接/移除全部选定的链接
| 插入新锚点，点击 插入锚点按钮 章节以查看更多内容。
| 插入新图像，点击 插入图像按钮 章节以查看更多内容。
| 清理代码/清除所有不需要的格式。此功能在你从office等产品中复制内容进来的时候特别有用。
| 显示此帮助窗口
| 打开HTML代码编辑器
| 在当前位置插入一张2×2的表格
| 在当前行的前面插入新行
| 在当前行的后面插入新行
| 删除当前行
| 在当前列的前面插入新列
| 在当前列的后面插入新列
| 删除当前列
| 插入水平线
| 移除所选文字的格式
| 将所选文字做为下标
| 将所选文字做为上标

返回 内容提要 | 顶部